@@ -1,9 +1,9 @@
 package Net::DNS::RR::CAA;
 
 #
-# $Id: CAA.pm 1741 2019-04-16 13:10:38Z willem $
+# $Id: CAA.pm 1781 2020-05-13 08:58:25Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1741 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1781 $)[1];
 
 
 use strict;
@@ -36,16 +36,14 @@ sub _decode_rdata {			## decode rdata from wire-format octet string
 sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	my $tag = $self->{tag};
-	pack 'C a* a*', $self->flags, $tag->encode, $self->{value}->raw;
+	pack 'C a* a*', $self->flags, $self->{tag}->encode, $self->{value}->raw;
 }
 
 
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	my $tag = $self->{tag};
-	my @rdata = ( $self->flags, $tag->string, $self->{value}->string );
+	my @rdata = ( $self->flags, $self->{tag}->string, $self->{value}->string );
 }
 
 
@@ -53,7 +51,7 @@ sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->flags(shift);
-	$self->tag(shift);
+	$self->tag( lc shift );
 	$self->value(shift);
 }
 
@@ -75,7 +73,7 @@ sub flags {
 
 sub critical {
 	for ( shift->{flags} ) {
-		$_ = ( shift() ? 0 : 0x0080 ) ^ ( 0x0080 | ( $_ || 0 ) ) if scalar @_;
+		$_ = ( $_[0] ? 0 : 0x0080 ) ^ ( 0x0080 | ( $_ || 0 ) ) if scalar @_;
 		return 0x0080 & ( $_ || 0 );
 	}
 }
@@ -148,7 +146,7 @@ Issuer critical flag.
 
 The property identifier, a sequence of ASCII characters.
 
-Tag values may contain ASCII characters a-z, A-Z, and 0-9.
+Tag values may contain ASCII characters a-z, hyphen and 0-9.
 Tag values should not contain any other characters.
 Matching of tag values is not case sensitive.
 
@@ -192,6 +190,6 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC6844
+L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC8659
 
 =cut
