@@ -1,9 +1,9 @@
 package Net::DNS::RR::ISDN;
 
 #
-# $Id: ISDN.pm 1528 2017-01-18 21:44:58Z willem $
+# $Id: ISDN.pm 1597 2017-09-22 08:04:02Z willem $
 #
-our $VERSION = (qw$LastChangedRevision: 1528 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1597 $)[1];
 
 
 use strict;
@@ -34,7 +34,7 @@ sub _decode_rdata {			## decode rdata from wire-format octet string
 sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	my $address = $self->{address} || return '';
+	my $address = $self->{address};
 	join '', $address->encode, $self->{sa}->encode;
 }
 
@@ -42,7 +42,7 @@ sub _encode_rdata {			## encode rdata as wire-format octet string
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	my $address = $self->{address} || return '';
+	my $address = $self->{address};
 	join ' ', $address->string, $self->{sa}->string;
 }
 
