@@ -1,13 +1,13 @@
 package Net::DNS::RR::KEY;
 
 #
-# $Id: KEY.pm 1381 2015-08-25 07:36:09Z willem $
+# $Id: KEY.pm 1779 2020-05-11 09:11:17Z willem $
 #
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1381 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1779 $)[1];
 
 
 use strict;
+use warnings;
 use base qw(Net::DNS::RR::DNSKEY);
 
 =head1 NAME
@@ -85,6 +85,9 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, L<Net::DNS::RR::DNSKEY>, RFC3755, RFC2535
+L<perl>, L<Net::DNS>, L<Net::DNS::RR>, L<Net::DNS::RR::DNSKEY>,
+RFC4034, RFC3755, RFC3008, RFC2535
+
+L<Algorithm Numbers|http://www.iana.org/assignments/dns-sec-alg-numbers>
 
 =cut
